@@ -42,6 +42,9 @@ VImageWidget::VImageWidget(QWidget *parent)
 
     setWindowFlags(windowFlags() | Qt::Window);
     setAttribute(Qt::WA_Maemo5StackedWindow);
+
+    connect(QApplication::desktop(), SIGNAL(resized(int)),
+	    this, SLOT(orientationChanged()));
 }
 
 void VImageWidget::setAuthor(const QString &author)
@@ -51,17 +54,31 @@ void VImageWidget::setAuthor(const QString &author)
 
 void VImageWidget::setPixmap(const QPixmap &pixmap)
 {
-    mImage->setPixmap(pixmap);
+    mImage->setPixmap(pixmap.scaled(800, 440, Qt::KeepAspectRatio,
+				    Qt::SmoothTransformation));
 }
 
 bool VImageWidget::event(QEvent *event)
 {
     if (event->type() == QEvent::Gesture)
 	return gestureEvent(static_cast<QGestureEvent*>(event));
+    else if (event->type() == QEvent::KeyPress)
+	return keyboardEvent(static_cast<QKeyEvent*>(event));
     else
 	return QWidget::event(event);
 }
 
+bool VImageWidget::keyboardEvent(QKeyEvent *event)
+{
+    if (event->key() == Qt::Key_Right)
+	emit next();
+
+    if (event->key() == Qt::Key_Left)
+	emit previous();
+
+    return true;
+}
+
 bool VImageWidget::gestureEvent(QGestureEvent *event)
 {
     QGesture *swipe = event->gesture(Qt::SwipeGesture);
@@ -85,3 +102,12 @@ bool VImageWidget::handleSwipe(QSwipeGesture *swipe)
 
     return true;
 }
+
+void VImageWidget::orientationChanged()
+{
+    QRect screenGeometry = QApplication::desktop()->screenGeometry();
+    if (screenGeometry.width() > screenGeometry.height())
+	qDebug() << "In landscape mode.";
+    else
+	qDebug() << "In portrait mode.";
+}
