@@ -26,6 +26,7 @@ class QString;
 class QLabel;
 class QPixmap;
 class QEvent;
+class QKeyEvent;
 class QGestureEvent;
 class QSwipeGesture;
 
@@ -46,7 +47,11 @@ signals:
     void next();
     void previous();
 
+private slots:
+    void orientationChanged();
+
 private:
+    bool keyboardEvent(QKeyEvent *event);
     bool gestureEvent(QGestureEvent *event);
     bool handleSwipe(QSwipeGesture *swipe);
 
