@@ -59,8 +59,7 @@ static QPixmap pixmapFromFile(const QString &name)
     QPixmap pixmap;
 
     if (!QPixmapCache::find(name, pixmap)) {
-	pixmap = QPixmap(QString("/opt/viito/data/%1").arg(name))
-	    .scaled(800, 480, Qt::KeepAspectRatio, Qt::SmoothTransformation);
+	pixmap = QPixmap(QString("/opt/viito/data/%1").arg(name));
 	QPixmapCache::insert(name, pixmap);
     }
 
@@ -79,17 +78,37 @@ VMainWindow::VMainWindow(const QString &file)
     setModel(doc);
 
     mTopicView = new QListView(this);
-    mTopicView->setModel(mModel);
+    mTopicView->setModel(mTopicModel);
+
+    mSearchView = new QListView(this);
+    mSearchView->setModel(mSearchModel);
+    mSearchView->setWindowFlags(mSearchView->windowFlags() | Qt::Window);
+    mSearchView->setAttribute(Qt::WA_Maemo5StackedWindow);
+    mSearchView->setAttribute(Qt::WA_Maemo5AutoOrientation, true);
+    mSearchView->setWindowTitle(tr("All words"));
 
     mImageView = new QListView(this);
-    mImageView->setAttribute(Qt::WA_Maemo5StackedWindow);
     mImageView->setWindowFlags(mImageView->windowFlags() | Qt::Window);
+    mImageView->setAttribute(Qt::WA_Maemo5StackedWindow);
+    mImageView->setAttribute(Qt::WA_Maemo5AutoOrientation, true);
 
     mImageWidget = new VImageWidget(mImageView);
 
+    QAction *aboutAction = new QAction(tr("About"), this);
+    QAction *searchAction = new QAction(tr("Search"), this);
+
+    menuBar()->addAction(aboutAction);
+    menuBar()->addAction(searchAction);
+
+    connect(aboutAction, SIGNAL(triggered()), this, SLOT(about()));
+    connect(searchAction, SIGNAL(triggered()), this, SLOT(search()));
+
     connect(mTopicView, SIGNAL(clicked(const QModelIndex&)),
 	    this, SLOT(topicClicked(const QModelIndex&)));
 
+    connect(mSearchView, SIGNAL(clicked(const QModelIndex&)),
+	    this, SLOT(imageClicked(const QModelIndex&)));
+
     connect(mImageView, SIGNAL(clicked(const QModelIndex&)),
 	    this, SLOT(imageClicked(const QModelIndex&)));
 
@@ -100,12 +119,13 @@ VMainWindow::VMainWindow(const QString &file)
 	    this, SLOT(previousImage()));
 
     setAttribute(Qt::WA_Maemo5StackedWindow);
+    setAttribute(Qt::WA_Maemo5AutoOrientation, true);
     setCentralWidget(mTopicView);
 }
 
 void VMainWindow::setModel(const QDomDocument &doc)
 {
-    mModel = new QStandardItemModel;
+    mTopicModel = new QStandardItemModel;
     mSearchModel = new QStandardItemModel;
 
     QDomNodeList topics = doc.elementsByTagName("topic");
@@ -120,7 +140,7 @@ void VMainWindow::setModel(const QDomDocument &doc)
 
 	QDomNodeList images = node.childNodes();
 
-	QStandardItem *topic = new QStandardItem(name);
+	VStandardItem *topic = new VStandardItem(name);
 	topic->setTextAlignment(Qt::AlignCenter);
 	topic->setEditable(false);
 
@@ -130,9 +150,9 @@ void VMainWindow::setModel(const QDomDocument &doc)
 	for (int j = 0; j < images.count(); j++) {
 
 	    QDomNamedNodeMap imgattrs = images.at(j).attributes();
-	    QStandardItem *image;
+	    VStandardItem *image;
 
-	    image = new QStandardItem(imgattrs.namedItem("name").nodeValue());
+	    image = new VStandardItem(imgattrs.namedItem("name").nodeValue());
 
 	    image->setData(imgattrs.namedItem("author").nodeValue(),
 			   VMainWindow::AuthorRole);
@@ -145,10 +165,11 @@ void VMainWindow::setModel(const QDomDocument &doc)
 	    imageModel->appendRow(image);
 	    mSearchModel->appendRow(image->clone());
 	}
-	mModel->appendRow(topic);
+	imageModel->sort(Qt::AscendingOrder);
+	mTopicModel->appendRow(topic);
     }
-    mModel->sort(0);
-    mSearchModel->sort(0);
+    mTopicModel->sort(Qt::AscendingOrder);
+    mSearchModel->sort(Qt::AscendingOrder);
 }
 
 void VMainWindow::topicClicked(const QModelIndex &index)
@@ -157,9 +178,7 @@ void VMainWindow::topicClicked(const QModelIndex &index)
     QStandardItemModel *model = (QStandardItemModel *)variant.value<void *>();
 
     mImageView->setModel(model);
-    mImageView->setWindowTitle(QString("%1 | %2")
-			       .arg(windowTitle())
-			       .arg(QString(index.data().value<QString>())));
+    mImageView->setWindowTitle(index.data().value<QString>());
     mImageView->show();
 }
 
@@ -185,9 +204,7 @@ void VMainWindow::setImage(const QModelIndex &index, int offset)
     }
 
     QString author = QString(" %1").arg(next.data(AuthorRole).toString());
-    QString title = QString("%1 | %2")
-	.arg(mImageView->windowTitle())
-	.arg(next.data().toString());
+    QString title = next.data().toString();
     QPixmap pixmap = pixmapFromFile(next.data(PathRole).toString());
 
     mImageWidget->setWindowTitle(title);
@@ -207,5 +224,11 @@ void VMainWindow::previousImage()
 
 void VMainWindow::about()
 {
-    qDebug() << "About.";
+    QMessageBox::information(this, tr("About Viito"),
+			     tr("Copyright  2010 Aki Niemi"));
+}
+
+void VMainWindow::search()
+{
+    mSearchView->show();
 }
